@@ -15,26 +15,28 @@
                    ##     message(pars[[1]])
                    ## },
                    "ID_NOT_FOUND" = {
-                       stop(paste0("Item not found: ", lpars))
+                       stop(paste0("Item not found: ", lpars), call.=F)
                    },
                    "ID_EXISTING" = {
-                       stop(paste0("There is already an item with this name: ", lpars))
+                       stop(paste0("There is already an item with this name: ", lpars),
+                            call.=F)
                    },
                    "ID_RESERVED" = {
-                       stop(paste0("Id not valid (reserved): ", lpars))
+                       stop(paste0("Id not valid (reserved): ", lpars), call.=F)
                    },
                    "TAG_RESERVED" = {
-                       warning(paste0("Reserved TAG used: ", lpars))
+                       warning(paste0("Reserved TAG used: ", lpars), call.=F)
                    },
                    "EMPTY_REPO" = {
-                       stop("Repo is empty.")
+                       stop("Repo is empty.", call.=F)
                    },
                    "MISS_OBJ_HAS_URL" = {
                        stop(paste0("The file object could not be found. ",
-                                   "However, it can be downloaded using pull."))
+                                   "However, it can be downloaded using pull."),
+                            call.=F)
                    },
                    "NO_URL" = {
-                       stop("The object has no associated URL.")
+                       stop("The object has no associated URL.", call.=F)
                    },
                    "LAZY_FOUND" = {
                        message("lazydo found precomputed resource.")
@@ -42,31 +44,30 @@
                    "LAZY_NOT_FOUND" = {
                        message("lazydo is building resource from code.")
                    },
-                   "LAZY_NOT_EXPR" = {
-                       stop("expr must be of class expression.")
-                   },
                    "LAZY_NAME" = {
                        message(paste0("Cached item name is: ", lpars))
                    },
                    "DATA_ALREADY_THERE" = {
                        stop(paste0("There is existing content for ", lpars, ". ",
-                                   "Use replace=T to overwrite."))
+                                   "Use replace=T to overwrite."), call.=F)
                    },
                    "ATTACHMENT_FILE_NOT_FOUND" = {
-                       stop(paste0("Attachment file not found: ", lpars))
+                       stop(paste0("Attachment file not found: ", lpars), call.=F)
                    },
                    "INFO_BUILDING_DEPS" = {
                        message(paste("Building dependency:", lpars))
                    },
                    "CHUNK_NOSOURCE" = {
-                       stop(paste("The following items have no associated source code object:", lpars))
+                       stop(paste("The following items have no associated source code object:",
+                                  lpars), call.=F)
                    },
                    "CHUNK_NOCHUNK" = {
-                       stop(paste("The following items have no associated code chunk:", lpars))
+                       stop(paste("The following items have no associated code chunk:", lpars),
+                            call.=F)
                    },
                    "FORK_CONFLICT" = {
                        stop(paste("The following forks are all active and contain the same item:",
-                                  lpars))
+                                  lpars), call.=F)
                    },
                    "FORK_NOACTIVEFORK" = {
                        stop(paste("None of the active forks contain the following item:", lpars))
@@ -80,15 +81,15 @@
                    },
                    "CHECK_MD5_WARNING_FAILED" = {
                        message(" changed!")
-                       warning("Item file has changed!")
+                       warning("Item file has changed!", call.=F)
                    },
                    "CHECK_MD5_WARNING_NOTFOUND" = {
                        message(" not found!")
-                       warning("Item file was not found!")
+                       warning("Item file was not found!", call.=F)
                    },
                    "CHECK_MD5_WARNING_NOTFOUND" = {
                        message(" not found!")
-                       warning("Item file was not found!")
+                       warning("Item file was not found!", call.=F)
                    },
                    "CHECK_EXTRA_INFO_STARTING" = {
                        message(paste0("\nChecking for extraneous ",
@@ -643,6 +644,7 @@ getSource <- function(name)
     ## matching
     findEntries <- function(tags=NULL, tagfun="OR", find=NULL)
         {
+          
             if(!is.null(tags)) {
                    tagsets <- lapply(entries, get, x="tags")
 
@@ -720,7 +722,7 @@ getSource <- function(name)
     ## ** creates a table with all items metadata to be shown by
     ## print. Currently filters are applied in the end, which slows
     ## down the process. The flags column is currently not used.
-    entriesToMat <- function(w)
+    entriesToMat <- function(w, flags=F)
         {
             entr <- entries[w]
 
@@ -730,22 +732,23 @@ getSource <- function(name)
             a <- matrix(NA, length(names), length(labels))
             colnames(a) <- labels
 
-            attachs <- depends <- hasattach <- allows <- rep(" ", length(entr))
-                            
             tagsets <- lapply(entr, get, x="tags")
-            attachs[sapply(tagsets, is.element, el="attachment")] <- "x"
-            depends[sapply(lapply(entr, get, x="depends"), length)>0] <- "x"
-            allows[!sapply(lapply(names, dependants), length)>0] <- "x"
-            hasattach[!sapply((sapply(names, attachments)), is.null)] <- "x"            
+            attachs <- rep(" ", length(entr))
+            if(flags) {
+              depends <- hasattach <- allows <- attachs
+              depends[sapply(lapply(entr, get, x="depends"), length)>0] <- "x"
+              allows[!sapply(lapply(names, dependants), length)>0] <- "x"
+              hasattach[!sapply((sapply(names, attachments)), is.null)] <- "x"
+              flags <- paste0(attachs, hasattach, depends, allows)            
+              a[,2] <- flags
+            }
 
-            flags <- paste0(attachs, hasattach, depends, allows)
-            
+            attachs[sapply(tagsets, is.element, el="attachment")] <- "x"
             descriptions <- sapply(entr, get, x="description")
             prefixes <- rep("", length(names))
-            prefixes[attachs == "x"] <- "@"                        
+            prefixes[attachs == "x"] <- "@"
 
             a[,"ID"] <- paste0(prefixes, names)
-            a[,2] <- flags
             a[,"Dims"] <- sapply(lapply(entr, get, x="dims"), paste, collapse="x");
             a[a[,"Dims"]=="", "Dims"] <- "-"            
             a[,"Tags"] <- sapply(tagsets, paste, collapse=", ")
